@@ -1,9 +1,9 @@
 import pytest
 from selenium import webdriver
-from time import sleep
+chrome_driver = r"C:\Program Files\Google\Chrome\Application\chromedriver.exe"
 import os
 import allure
-from selenium.webdriver.common.by import By
+
 
 _driver = None
 
@@ -28,10 +28,10 @@ def pytest_runtest_makereport(item, call):
             allure.attach(_driver.get_screenshot_as_png(), "失败截图", allure.attachment_type.PNG)
 
 
-@pytest.fixture(scope="session")
+@pytest.fixture(scope='session')
 def browser():
     global _driver
     if _driver is None:
-        _driver =webdriver.Chrome()
+        _driver =webdriver.Chrome(executable_path=chrome_driver)
     yield _driver
-    # _driver.quit()
+    _driver.quit()
\ No newline at end of file
